Class: CloudsmithApi::BulkActionApi
- Inherits:
-
Object
- Object
- CloudsmithApi::BulkActionApi
- Defined in:
- lib/cloudsmith-api/api/bulk_action_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#bulk_action(owner, opts = {}) ⇒ PackageBulkActionResponse
Perform bulk operations on multiple packages within a repository or across all accessible repositories.
-
#bulk_action_with_http_info(owner, opts = {}) ⇒ Array<(PackageBulkActionResponse, Fixnum, Hash)>
Perform bulk operations on multiple packages within a repository or across all accessible repositories.
-
#initialize(api_client = ApiClient.default) ⇒ BulkActionApi
constructor
A new instance of BulkActionApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BulkActionApi
Returns a new instance of BulkActionApi.
19 20 21 |
# File 'lib/cloudsmith-api/api/bulk_action_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cloudsmith-api/api/bulk_action_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#bulk_action(owner, opts = {}) ⇒ PackageBulkActionResponse
Perform bulk operations on multiple packages within a repository or across all accessible repositories. If ‘repository’ is provided, actions are limited to that repository. If ‘repository’ is omitted, actions are performed across all repositories the user has access to within the workspace. Returns a list of successfully actioned packages and any packages that failed with error details.
27 28 29 30 |
# File 'lib/cloudsmith-api/api/bulk_action_api.rb', line 27 def bulk_action(owner, opts = {}) data, _status_code, _headers = bulk_action_with_http_info(owner, opts) data end |
#bulk_action_with_http_info(owner, opts = {}) ⇒ Array<(PackageBulkActionResponse, Fixnum, Hash)>
Perform bulk operations on multiple packages within a repository or across all accessible repositories. If 'repository' is provided, actions are limited to that repository. If 'repository' is omitted, actions are performed across all repositories the user has access to within the workspace. Returns a list of successfully actioned packages and any packages that failed with error details.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/cloudsmith-api/api/bulk_action_api.rb', line 37 def bulk_action_with_http_info(owner, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BulkActionApi.bulk_action ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling BulkActionApi.bulk_action" end # resource path local_var_path = '/bulk-action/{owner}/'.sub('{' + 'owner' + '}', owner.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'data']) auth_names = ['apikey', 'basic'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PackageBulkActionResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: BulkActionApi#bulk_action\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |