Class: CloudsmithApi::OpenidApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudsmith-api/api/openid_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ OpenidApi

Returns a new instance of OpenidApi.



19
20
21
# File 'lib/cloudsmith-api/api/openid_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cloudsmith-api/api/openid_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#openid_create(owner, opts = {}) ⇒ Oidc1

Get a JWT token for a configured service account belonging to the requesting org. Get a JWT token for a configured service account belonging to the requesting org.

Parameters:

  • owner
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



28
29
30
31
# File 'lib/cloudsmith-api/api/openid_api.rb', line 28

def openid_create(owner, opts = {})
  data, _status_code, _headers = openid_create_with_http_info(owner, opts)
  data
end

#openid_create_with_http_info(owner, opts = {}) ⇒ Array<(Oidc1, Fixnum, Hash)>

Get a JWT token for a configured service account belonging to the requesting org. Get a JWT token for a configured service account belonging to the requesting org.

Parameters:

  • owner
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(Oidc1, Fixnum, Hash)>)

    Oidc1 data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/cloudsmith-api/api/openid_api.rb', line 39

def openid_create_with_http_info(owner, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: OpenidApi.openid_create ...'
  end
  # verify the required parameter 'owner' is set
  if @api_client.config.client_side_validation && owner.nil?
    fail ArgumentError, "Missing the required parameter 'owner' when calling OpenidApi.openid_create"
  end
  # resource path
  local_var_path = '/openid/{owner}/'.sub('{' + 'owner' + '}', owner.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(opts[:'data'])
  auth_names = ['apikey', 'basic']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'Oidc1')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: OpenidApi#openid_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end