Class: CloudsmithApi::OrganizationApiKeyRule

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudsmith-api/models/organization_api_key_rule.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OrganizationApiKeyRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 96

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.has_key?(:'enforce_refresh')
    self.enforce_refresh = attributes[:'enforce_refresh']
  end

  if attributes.has_key?(:'is_enabled')
    self.is_enabled = attributes[:'is_enabled']
  end

  if attributes.has_key?(:'last_applied_at')
    self.last_applied_at = attributes[:'last_applied_at']
  end

  if attributes.has_key?(:'max_age_hours')
    self.max_age_hours = attributes[:'max_age_hours']
  end

  if attributes.has_key?(:'rule_type')
    self.rule_type = attributes[:'rule_type']
  end

  if attributes.has_key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.has_key?(:'slug_perm')
    self.slug_perm = attributes[:'slug_perm']
  end

  if attributes.has_key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



17
18
19
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 17

def created_at
  @created_at
end

#enforce_refreshObject

When enabled, API keys that violate the organization's rule will be replaced automatically.



20
21
22
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 20

def enforce_refresh
  @enforce_refresh
end

#is_enabledObject

Whether this rule is currently active and enforced.



23
24
25
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 23

def is_enabled
  @is_enabled
end

#last_applied_atObject

The last time this rule was evaluated and applied by the expiry task.



26
27
28
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 26

def last_applied_at
  @last_applied_at
end

#max_age_hoursObject

The maximum permitted age of an API key for use in the organization. API keys older than this will no longer have access until they are refreshed. To disable the rule unset this value.



29
30
31
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 29

def max_age_hours
  @max_age_hours
end

#rule_typeObject

Specify which account types this rule applies to: all accounts (deprecated — prefer separate service/user rules), service accounts only, or user accounts only.



32
33
34
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 32

def rule_type
  @rule_type
end

#slugObject

Human-readable identifier for the rule type. Automatically generated based on the rule type.



35
36
37
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 35

def slug
  @slug
end

#slug_permObject

An auto-generated id that uniquely identifies the API key policy.



38
39
40
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 38

def slug_perm
  @slug_perm
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 40

def updated_at
  @updated_at
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 65

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'enforce_refresh' => :'enforce_refresh',
    :'is_enabled' => :'is_enabled',
    :'last_applied_at' => :'last_applied_at',
    :'max_age_hours' => :'max_age_hours',
    :'rule_type' => :'rule_type',
    :'slug' => :'slug',
    :'slug_perm' => :'slug_perm',
    :'updated_at' => :'updated_at'
  }
end

.swagger_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 80

def self.swagger_types
  {
    :'created_at' => :'DateTime',
    :'enforce_refresh' => :'BOOLEAN',
    :'is_enabled' => :'BOOLEAN',
    :'last_applied_at' => :'DateTime',
    :'max_age_hours' => :'Integer',
    :'rule_type' => :'String',
    :'slug' => :'String',
    :'slug_perm' => :'String',
    :'updated_at' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      enforce_refresh == o.enforce_refresh &&
      is_enabled == o.is_enabled &&
      last_applied_at == o.last_applied_at &&
      max_age_hours == o.max_age_hours &&
      rule_type == o.rule_type &&
      slug == o.slug &&
      slug_perm == o.slug_perm &&
      updated_at == o.updated_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 221

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CloudsmithApi.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 287

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 200

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 187

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



193
194
195
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 193

def hash
  [created_at, enforce_refresh, is_enabled, last_applied_at, max_age_hours, rule_type, slug, slug_perm, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 141

def list_invalid_properties
  invalid_properties = Array.new
  if @rule_type.nil?
    invalid_properties.push('invalid value for "rule_type", rule_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 267

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



273
274
275
276
277
278
279
280
281
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 273

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



261
262
263
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 261

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
# File 'lib/cloudsmith-api/models/organization_api_key_rule.rb', line 152

def valid?
  return false if @rule_type.nil?
  rule_type_validator = EnumAttributeValidator.new('String', ['All Accounts', 'Service Accounts', 'User Accounts'])
  return false unless rule_type_validator.valid?(@rule_type)
  true
end