Class: CloudsmithApi::OrganizationApiKeyRuleRequestPatch
- Inherits:
-
Object
- Object
- CloudsmithApi::OrganizationApiKeyRuleRequestPatch
- Defined in:
- lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#enforce_refresh ⇒ Object
When enabled, API keys that violate the organization's rule will be replaced automatically.
-
#is_enabled ⇒ Object
Whether this rule is currently active and enforced.
-
#max_age_hours ⇒ Object
The maximum permitted age of an API key for use in the organization.
-
#refresh_immediately ⇒ Object
If set to True, API keys that violate this rule will be replaced immediately after the request is made.
-
#rule_type ⇒ Object
Specify which account types this rule applies to: all accounts (deprecated — prefer separate service/user rules), service accounts only, or user accounts only.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrganizationApiKeyRuleRequestPatch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OrganizationApiKeyRuleRequestPatch
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'enforce_refresh') self.enforce_refresh = attributes[:'enforce_refresh'] end if attributes.has_key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] end if attributes.has_key?(:'max_age_hours') self.max_age_hours = attributes[:'max_age_hours'] end if attributes.has_key?(:'refresh_immediately') self.refresh_immediately = attributes[:'refresh_immediately'] end if attributes.has_key?(:'rule_type') self.rule_type = attributes[:'rule_type'] end end |
Instance Attribute Details
#enforce_refresh ⇒ Object
When enabled, API keys that violate the organization's rule will be replaced automatically.
18 19 20 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 18 def enforce_refresh @enforce_refresh end |
#is_enabled ⇒ Object
Whether this rule is currently active and enforced.
21 22 23 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 21 def is_enabled @is_enabled end |
#max_age_hours ⇒ Object
The maximum permitted age of an API key for use in the organization. API keys older than this will no longer have access until they are refreshed. To disable the rule unset this value.
24 25 26 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 24 def max_age_hours @max_age_hours end |
#refresh_immediately ⇒ Object
If set to True, API keys that violate this rule will be replaced immediately after the request is made. There is no way to undo this.
27 28 29 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 27 def refresh_immediately @refresh_immediately end |
#rule_type ⇒ Object
Specify which account types this rule applies to: all accounts (deprecated — prefer separate service/user rules), service accounts only, or user accounts only.
30 31 32 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 30 def rule_type @rule_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 55 def self.attribute_map { :'enforce_refresh' => :'enforce_refresh', :'is_enabled' => :'is_enabled', :'max_age_hours' => :'max_age_hours', :'refresh_immediately' => :'refresh_immediately', :'rule_type' => :'rule_type' } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 66 def self.swagger_types { :'enforce_refresh' => :'BOOLEAN', :'is_enabled' => :'BOOLEAN', :'max_age_hours' => :'Integer', :'refresh_immediately' => :'BOOLEAN', :'rule_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 132 def ==(o) return true if self.equal?(o) self.class == o.class && enforce_refresh == o.enforce_refresh && is_enabled == o.is_enabled && max_age_hours == o.max_age_hours && refresh_immediately == o.refresh_immediately && rule_type == o.rule_type end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 178 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CloudsmithApi.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 244 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
144 145 146 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 144 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 150 def hash [enforce_refresh, is_enabled, max_age_hours, refresh_immediately, rule_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 107 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
224 225 226 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 224 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
230 231 232 233 234 235 236 237 238 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 230 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 218 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 118 |
# File 'lib/cloudsmith-api/models/organization_api_key_rule_request_patch.rb', line 114 def valid? rule_type_validator = EnumAttributeValidator.new('String', ['All Accounts', 'Service Accounts', 'User Accounts']) return false unless rule_type_validator.valid?(@rule_type) true end |