Class: CloudsmithApi::OrganizationPackageVulnerabilityPolicy
- Inherits:
-
Object
- Object
- CloudsmithApi::OrganizationPackageVulnerabilityPolicy
- Defined in:
- lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allow_unknown_severity ⇒ Object
Denotes whether vulnerabilities detected by a security scan with an unknown severity are permitted by this policy.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#min_severity ⇒ Object
Returns the value of attribute min_severity.
-
#name ⇒ Object
Returns the value of attribute name.
-
#on_violation_quarantine ⇒ Object
Returns the value of attribute on_violation_quarantine.
-
#slug_perm ⇒ Object
Returns the value of attribute slug_perm.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrganizationPackageVulnerabilityPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OrganizationPackageVulnerabilityPolicy
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'allow_unknown_severity') self.allow_unknown_severity = attributes[:'allow_unknown_severity'] end if attributes.has_key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'min_severity') self.min_severity = attributes[:'min_severity'] else self.min_severity = 'Critical' end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'on_violation_quarantine') self.on_violation_quarantine = attributes[:'on_violation_quarantine'] end if attributes.has_key?(:'slug_perm') self.slug_perm = attributes[:'slug_perm'] end if attributes.has_key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#allow_unknown_severity ⇒ Object
Denotes whether vulnerabilities detected by a security scan with an unknown severity are permitted by this policy.
18 19 20 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 18 def allow_unknown_severity @allow_unknown_severity end |
#created_at ⇒ Object
Returns the value of attribute created_at.
20 21 22 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 20 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 22 def description @description end |
#min_severity ⇒ Object
Returns the value of attribute min_severity.
24 25 26 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 24 def min_severity @min_severity end |
#name ⇒ Object
Returns the value of attribute name.
26 27 28 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 26 def name @name end |
#on_violation_quarantine ⇒ Object
Returns the value of attribute on_violation_quarantine.
28 29 30 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 28 def on_violation_quarantine @on_violation_quarantine end |
#slug_perm ⇒ Object
Returns the value of attribute slug_perm.
30 31 32 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 30 def slug_perm @slug_perm end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
32 33 34 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 32 def updated_at @updated_at end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 57 def self.attribute_map { :'allow_unknown_severity' => :'allow_unknown_severity', :'created_at' => :'created_at', :'description' => :'description', :'min_severity' => :'min_severity', :'name' => :'name', :'on_violation_quarantine' => :'on_violation_quarantine', :'slug_perm' => :'slug_perm', :'updated_at' => :'updated_at' } end |
.swagger_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 71 def self.swagger_types { :'allow_unknown_severity' => :'BOOLEAN', :'created_at' => :'DateTime', :'description' => :'String', :'min_severity' => :'String', :'name' => :'String', :'on_violation_quarantine' => :'BOOLEAN', :'slug_perm' => :'String', :'updated_at' => :'DateTime' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 159 def ==(o) return true if self.equal?(o) self.class == o.class && allow_unknown_severity == o.allow_unknown_severity && created_at == o.created_at && description == o.description && min_severity == o.min_severity && name == o.name && on_violation_quarantine == o.on_violation_quarantine && slug_perm == o.slug_perm && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 208 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CloudsmithApi.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 274 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 187 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
174 175 176 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 174 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 180 def hash [allow_unknown_severity, created_at, description, min_severity, name, on_violation_quarantine, slug_perm, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 134 135 136 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 129 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
254 255 256 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 254 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
248 249 250 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 248 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 144 145 |
# File 'lib/cloudsmith-api/models/organization_package_vulnerability_policy.rb', line 140 def valid? min_severity_validator = EnumAttributeValidator.new('String', ['Low', 'Medium', 'High', 'Critical']) return false unless min_severity_validator.valid?(@min_severity) return false if @name.nil? true end |