Class: CloudsmithApi::PackageLicenseRequestPatch

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudsmith-api/models/package_license_request_patch.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PackageLicenseRequestPatch

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 82

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = 'Update'
  end

  if attributes.has_key?(:'is_malware_detected')
    self.is_malware_detected = attributes[:'is_malware_detected']
  end

  if attributes.has_key?(:'license_notes')
    self.license_notes = attributes[:'license_notes']
  end

  if attributes.has_key?(:'license_override')
    self.license_override = attributes[:'license_override']
  else
    self.license_override = 'None'
  end

  if attributes.has_key?(:'license_url')
    self.license_url = attributes[:'license_url']
  end

  if attributes.has_key?(:'spdx_license')
    self.spdx_license = attributes[:'spdx_license']
  end

  if attributes.has_key?(:'vulnerability_counts')
    self.vulnerability_counts = attributes[:'vulnerability_counts']
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



17
18
19
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 17

def action
  @action
end

#is_malware_detectedObject

Whether the package has been detected as containing malware. Requires Ultra plan.



20
21
22
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 20

def is_malware_detected
  @is_malware_detected
end

#license_notesObject

Returns the value of attribute license_notes.



22
23
24
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 22

def license_notes
  @license_notes
end

#license_overrideObject

Returns the value of attribute license_override.



24
25
26
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 24

def license_override
  @license_override
end

#license_urlObject

Returns the value of attribute license_url.



26
27
28
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 26

def license_url
  @license_url
end

#spdx_licenseObject

Returns the value of attribute spdx_license.



28
29
30
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 28

def spdx_license
  @spdx_license
end

#vulnerability_countsObject

Returns the value of attribute vulnerability_counts.



30
31
32
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 30

def vulnerability_counts
  @vulnerability_counts
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 55

def self.attribute_map
  {
    :'action' => :'action',
    :'is_malware_detected' => :'is_malware_detected',
    :'license_notes' => :'license_notes',
    :'license_override' => :'license_override',
    :'license_url' => :'license_url',
    :'spdx_license' => :'spdx_license',
    :'vulnerability_counts' => :'vulnerability_counts'
  }
end

.swagger_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 68

def self.swagger_types
  {
    :'action' => :'String',
    :'is_malware_detected' => :'BOOLEAN',
    :'license_notes' => :'String',
    :'license_override' => :'String',
    :'license_url' => :'String',
    :'spdx_license' => :'String',
    :'vulnerability_counts' => :'WebOSVSeverityCounts'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
173
174
175
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      is_malware_detected == o.is_malware_detected &&
      license_notes == o.license_notes &&
      license_override == o.license_override &&
      license_url == o.license_url &&
      spdx_license == o.spdx_license &&
      vulnerability_counts == o.vulnerability_counts
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 213

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CloudsmithApi.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 279

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 192

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 179

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



185
186
187
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 185

def hash
  [action, is_malware_detected, license_notes, license_override, license_url, spdx_license, vulnerability_counts].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



123
124
125
126
127
128
129
130
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 123

def list_invalid_properties
  invalid_properties = Array.new
  if @spdx_license.nil?
    invalid_properties.push('invalid value for "spdx_license", spdx_license cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 259

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



253
254
255
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 253

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
138
139
140
141
# File 'lib/cloudsmith-api/models/package_license_request_patch.rb', line 134

def valid?
  action_validator = EnumAttributeValidator.new('String', ['Update'])
  return false unless action_validator.valid?(@action)
  license_override_validator = EnumAttributeValidator.new('String', ['None', 'Ignored', 'Purchased'])
  return false unless license_override_validator.valid?(@license_override)
  return false if @spdx_license.nil?
  true
end