Class: CloudsmithApi::PackageStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudsmith-api/models/package_status.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PackageStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/cloudsmith-api/models/package_status.rb', line 138

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'is_cancellable')
    self.is_cancellable = attributes[:'is_cancellable']
  end

  if attributes.has_key?(:'is_copyable')
    self.is_copyable = attributes[:'is_copyable']
  end

  if attributes.has_key?(:'is_deleteable')
    self.is_deleteable = attributes[:'is_deleteable']
  end

  if attributes.has_key?(:'is_downloadable')
    self.is_downloadable = attributes[:'is_downloadable']
  end

  if attributes.has_key?(:'is_hidden')
    self.is_hidden = attributes[:'is_hidden']
  end

  if attributes.has_key?(:'is_moveable')
    self.is_moveable = attributes[:'is_moveable']
  end

  if attributes.has_key?(:'is_quarantinable')
    self.is_quarantinable = attributes[:'is_quarantinable']
  end

  if attributes.has_key?(:'is_quarantined')
    self.is_quarantined = attributes[:'is_quarantined']
  end

  if attributes.has_key?(:'is_resyncable')
    self.is_resyncable = attributes[:'is_resyncable']
  end

  if attributes.has_key?(:'is_security_scannable')
    self.is_security_scannable = attributes[:'is_security_scannable']
  end

  if attributes.has_key?(:'is_sync_awaiting')
    self.is_sync_awaiting = attributes[:'is_sync_awaiting']
  end

  if attributes.has_key?(:'is_sync_completed')
    self.is_sync_completed = attributes[:'is_sync_completed']
  end

  if attributes.has_key?(:'is_sync_failed')
    self.is_sync_failed = attributes[:'is_sync_failed']
  end

  if attributes.has_key?(:'is_sync_in_flight')
    self.is_sync_in_flight = attributes[:'is_sync_in_flight']
  end

  if attributes.has_key?(:'is_sync_in_progress')
    self.is_sync_in_progress = attributes[:'is_sync_in_progress']
  end

  if attributes.has_key?(:'self_url')
    self.self_url = attributes[:'self_url']
  end

  if attributes.has_key?(:'stage')
    self.stage = attributes[:'stage']
  end

  if attributes.has_key?(:'stage_str')
    self.stage_str = attributes[:'stage_str']
  end

  if attributes.has_key?(:'stage_updated_at')
    self.stage_updated_at = attributes[:'stage_updated_at']
  end

  if attributes.has_key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.has_key?(:'status_reason')
    self.status_reason = attributes[:'status_reason']
  end

  if attributes.has_key?(:'status_str')
    self.status_str = attributes[:'status_str']
  end

  if attributes.has_key?(:'status_updated_at')
    self.status_updated_at = attributes[:'status_updated_at']
  end

  if attributes.has_key?(:'sync_finished_at')
    self.sync_finished_at = attributes[:'sync_finished_at']
  end

  if attributes.has_key?(:'sync_progress')
    self.sync_progress = attributes[:'sync_progress']
  end
end

Instance Attribute Details

#is_cancellableObject

Returns the value of attribute is_cancellable.



17
18
19
# File 'lib/cloudsmith-api/models/package_status.rb', line 17

def is_cancellable
  @is_cancellable
end

#is_copyableObject

Returns the value of attribute is_copyable.



19
20
21
# File 'lib/cloudsmith-api/models/package_status.rb', line 19

def is_copyable
  @is_copyable
end

#is_deleteableObject

Returns the value of attribute is_deleteable.



21
22
23
# File 'lib/cloudsmith-api/models/package_status.rb', line 21

def is_deleteable
  @is_deleteable
end

#is_downloadableObject

Returns the value of attribute is_downloadable.



23
24
25
# File 'lib/cloudsmith-api/models/package_status.rb', line 23

def is_downloadable
  @is_downloadable
end

#is_hiddenObject

Returns the value of attribute is_hidden.



25
26
27
# File 'lib/cloudsmith-api/models/package_status.rb', line 25

def is_hidden
  @is_hidden
end

#is_moveableObject

Returns the value of attribute is_moveable.



27
28
29
# File 'lib/cloudsmith-api/models/package_status.rb', line 27

def is_moveable
  @is_moveable
end

#is_quarantinableObject

Returns the value of attribute is_quarantinable.



29
30
31
# File 'lib/cloudsmith-api/models/package_status.rb', line 29

def is_quarantinable
  @is_quarantinable
end

#is_quarantinedObject

Returns the value of attribute is_quarantined.



31
32
33
# File 'lib/cloudsmith-api/models/package_status.rb', line 31

def is_quarantined
  @is_quarantined
end

#is_resyncableObject

Returns the value of attribute is_resyncable.



33
34
35
# File 'lib/cloudsmith-api/models/package_status.rb', line 33

def is_resyncable
  @is_resyncable
end

#is_security_scannableObject

Returns the value of attribute is_security_scannable.



35
36
37
# File 'lib/cloudsmith-api/models/package_status.rb', line 35

def is_security_scannable
  @is_security_scannable
end

#is_sync_awaitingObject

Returns the value of attribute is_sync_awaiting.



37
38
39
# File 'lib/cloudsmith-api/models/package_status.rb', line 37

def is_sync_awaiting
  @is_sync_awaiting
end

#is_sync_completedObject

Returns the value of attribute is_sync_completed.



39
40
41
# File 'lib/cloudsmith-api/models/package_status.rb', line 39

def is_sync_completed
  @is_sync_completed
end

#is_sync_failedObject

Returns the value of attribute is_sync_failed.



41
42
43
# File 'lib/cloudsmith-api/models/package_status.rb', line 41

def is_sync_failed
  @is_sync_failed
end

#is_sync_in_flightObject

Returns the value of attribute is_sync_in_flight.



43
44
45
# File 'lib/cloudsmith-api/models/package_status.rb', line 43

def is_sync_in_flight
  @is_sync_in_flight
end

#is_sync_in_progressObject

Returns the value of attribute is_sync_in_progress.



45
46
47
# File 'lib/cloudsmith-api/models/package_status.rb', line 45

def is_sync_in_progress
  @is_sync_in_progress
end

#self_urlObject

Returns the value of attribute self_url.



47
48
49
# File 'lib/cloudsmith-api/models/package_status.rb', line 47

def self_url
  @self_url
end

#stageObject

The synchronisation (in progress) stage of the package.



50
51
52
# File 'lib/cloudsmith-api/models/package_status.rb', line 50

def stage
  @stage
end

#stage_strObject

Returns the value of attribute stage_str.



52
53
54
# File 'lib/cloudsmith-api/models/package_status.rb', line 52

def stage_str
  @stage_str
end

#stage_updated_atObject

The datetime the package stage was updated at.



55
56
57
# File 'lib/cloudsmith-api/models/package_status.rb', line 55

def stage_updated_at
  @stage_updated_at
end

#statusObject

The synchronisation status of the package.



58
59
60
# File 'lib/cloudsmith-api/models/package_status.rb', line 58

def status
  @status
end

#status_reasonObject

A textual description for the synchronous status reason (if any



61
62
63
# File 'lib/cloudsmith-api/models/package_status.rb', line 61

def status_reason
  @status_reason
end

#status_strObject

Returns the value of attribute status_str.



63
64
65
# File 'lib/cloudsmith-api/models/package_status.rb', line 63

def status_str
  @status_str
end

#status_updated_atObject

The datetime the package status was updated at.



66
67
68
# File 'lib/cloudsmith-api/models/package_status.rb', line 66

def status_updated_at
  @status_updated_at
end

#sync_finished_atObject

The datetime the package sync was finished at.



69
70
71
# File 'lib/cloudsmith-api/models/package_status.rb', line 69

def sync_finished_at
  @sync_finished_at
end

#sync_progressObject

Synchronisation progress (from 0-100)



72
73
74
# File 'lib/cloudsmith-api/models/package_status.rb', line 72

def sync_progress
  @sync_progress
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/cloudsmith-api/models/package_status.rb', line 75

def self.attribute_map
  {
    :'is_cancellable' => :'is_cancellable',
    :'is_copyable' => :'is_copyable',
    :'is_deleteable' => :'is_deleteable',
    :'is_downloadable' => :'is_downloadable',
    :'is_hidden' => :'is_hidden',
    :'is_moveable' => :'is_moveable',
    :'is_quarantinable' => :'is_quarantinable',
    :'is_quarantined' => :'is_quarantined',
    :'is_resyncable' => :'is_resyncable',
    :'is_security_scannable' => :'is_security_scannable',
    :'is_sync_awaiting' => :'is_sync_awaiting',
    :'is_sync_completed' => :'is_sync_completed',
    :'is_sync_failed' => :'is_sync_failed',
    :'is_sync_in_flight' => :'is_sync_in_flight',
    :'is_sync_in_progress' => :'is_sync_in_progress',
    :'self_url' => :'self_url',
    :'stage' => :'stage',
    :'stage_str' => :'stage_str',
    :'stage_updated_at' => :'stage_updated_at',
    :'status' => :'status',
    :'status_reason' => :'status_reason',
    :'status_str' => :'status_str',
    :'status_updated_at' => :'status_updated_at',
    :'sync_finished_at' => :'sync_finished_at',
    :'sync_progress' => :'sync_progress'
  }
end

.swagger_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/cloudsmith-api/models/package_status.rb', line 106

def self.swagger_types
  {
    :'is_cancellable' => :'BOOLEAN',
    :'is_copyable' => :'BOOLEAN',
    :'is_deleteable' => :'BOOLEAN',
    :'is_downloadable' => :'BOOLEAN',
    :'is_hidden' => :'BOOLEAN',
    :'is_moveable' => :'BOOLEAN',
    :'is_quarantinable' => :'BOOLEAN',
    :'is_quarantined' => :'BOOLEAN',
    :'is_resyncable' => :'BOOLEAN',
    :'is_security_scannable' => :'BOOLEAN',
    :'is_sync_awaiting' => :'BOOLEAN',
    :'is_sync_completed' => :'BOOLEAN',
    :'is_sync_failed' => :'BOOLEAN',
    :'is_sync_in_flight' => :'BOOLEAN',
    :'is_sync_in_progress' => :'BOOLEAN',
    :'self_url' => :'String',
    :'stage' => :'Integer',
    :'stage_str' => :'String',
    :'stage_updated_at' => :'DateTime',
    :'status' => :'Integer',
    :'status_reason' => :'String',
    :'status_str' => :'String',
    :'status_updated_at' => :'DateTime',
    :'sync_finished_at' => :'DateTime',
    :'sync_progress' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/cloudsmith-api/models/package_status.rb', line 260

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      is_cancellable == o.is_cancellable &&
      is_copyable == o.is_copyable &&
      is_deleteable == o.is_deleteable &&
      is_downloadable == o.is_downloadable &&
      is_hidden == o.is_hidden &&
      is_moveable == o.is_moveable &&
      is_quarantinable == o.is_quarantinable &&
      is_quarantined == o.is_quarantined &&
      is_resyncable == o.is_resyncable &&
      is_security_scannable == o.is_security_scannable &&
      is_sync_awaiting == o.is_sync_awaiting &&
      is_sync_completed == o.is_sync_completed &&
      is_sync_failed == o.is_sync_failed &&
      is_sync_in_flight == o.is_sync_in_flight &&
      is_sync_in_progress == o.is_sync_in_progress &&
      self_url == o.self_url &&
      stage == o.stage &&
      stage_str == o.stage_str &&
      stage_updated_at == o.stage_updated_at &&
      status == o.status &&
      status_reason == o.status_reason &&
      status_str == o.status_str &&
      status_updated_at == o.status_updated_at &&
      sync_finished_at == o.sync_finished_at &&
      sync_progress == o.sync_progress
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/cloudsmith-api/models/package_status.rb', line 326

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CloudsmithApi.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/cloudsmith-api/models/package_status.rb', line 392

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/cloudsmith-api/models/package_status.rb', line 305

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


292
293
294
# File 'lib/cloudsmith-api/models/package_status.rb', line 292

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



298
299
300
# File 'lib/cloudsmith-api/models/package_status.rb', line 298

def hash
  [is_cancellable, is_copyable, is_deleteable, is_downloadable, is_hidden, is_moveable, is_quarantinable, is_quarantined, is_resyncable, is_security_scannable, is_sync_awaiting, is_sync_completed, is_sync_failed, is_sync_in_flight, is_sync_in_progress, self_url, stage, stage_str, stage_updated_at, status, status_reason, status_str, status_updated_at, sync_finished_at, sync_progress].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



247
248
249
250
# File 'lib/cloudsmith-api/models/package_status.rb', line 247

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



372
373
374
# File 'lib/cloudsmith-api/models/package_status.rb', line 372

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



378
379
380
381
382
383
384
385
386
# File 'lib/cloudsmith-api/models/package_status.rb', line 378

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



366
367
368
# File 'lib/cloudsmith-api/models/package_status.rb', line 366

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



254
255
256
# File 'lib/cloudsmith-api/models/package_status.rb', line 254

def valid?
  true
end