Class: CloudsmithApi::RecycleBinApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudsmith-api/api/recycle_bin_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RecycleBinApi

Returns a new instance of RecycleBinApi.



19
20
21
# File 'lib/cloudsmith-api/api/recycle_bin_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cloudsmith-api/api/recycle_bin_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#recycle_bin_list(owner, opts = {}) ⇒ Array<RecycleBinPackage>

List soft-deleted packages in recycle bin Retrieve all soft-deleted packages in the workspace. Optionally filter by repository using the ‘repository’ query parameter.

Parameters:

  • owner
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :repository (String)

    Filter packages by repository slug

Returns:



30
31
32
33
# File 'lib/cloudsmith-api/api/recycle_bin_api.rb', line 30

def recycle_bin_list(owner, opts = {})
  data, _status_code, _headers = recycle_bin_list_with_http_info(owner, opts)
  data
end

#recycle_bin_list_with_http_info(owner, opts = {}) ⇒ Array<(Array<RecycleBinPackage>, Fixnum, Hash)>

List soft-deleted packages in recycle bin Retrieve all soft-deleted packages in the workspace. Optionally filter by repository using the &#39;repository&#39; query parameter.

Parameters:

  • owner
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :repository (String)

    Filter packages by repository slug

Returns:

  • (Array<(Array<RecycleBinPackage>, Fixnum, Hash)>)

    Array<RecycleBinPackage> data, response status code and response headers



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/cloudsmith-api/api/recycle_bin_api.rb', line 43

def recycle_bin_list_with_http_info(owner, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RecycleBinApi.recycle_bin_list ...'
  end
  # verify the required parameter 'owner' is set
  if @api_client.config.client_side_validation && owner.nil?
    fail ArgumentError, "Missing the required parameter 'owner' when calling RecycleBinApi.recycle_bin_list"
  end
  # resource path
  local_var_path = '/recycle-bin/{owner}/'.sub('{' + 'owner' + '}', owner.to_s)

  # query parameters
  query_params = {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'repository'] = opts[:'repository'] if !opts[:'repository'].nil?

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['apikey', 'basic']
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'Array<RecycleBinPackage>')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RecycleBinApi#recycle_bin_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#recycle_bin_recycle_bin_action(owner, opts = {}) ⇒ PackageBulkActionResponse

Perform actions on soft-deleted packages in the recycle bin. Supported actions: permanently delete (hard delete), restore. Returns a list of successfully actioned packages and any packages that failed with error details.

Parameters:

  • owner
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



90
91
92
93
# File 'lib/cloudsmith-api/api/recycle_bin_api.rb', line 90

def recycle_bin_recycle_bin_action(owner, opts = {})
  data, _status_code, _headers = recycle_bin_recycle_bin_action_with_http_info(owner, opts)
  data
end

#recycle_bin_recycle_bin_action_with_http_info(owner, opts = {}) ⇒ Array<(PackageBulkActionResponse, Fixnum, Hash)>

Perform actions on soft-deleted packages in the recycle bin. Supported actions: permanently delete (hard delete), restore. Returns a list of successfully actioned packages and any packages that failed with error details.

Parameters:

  • owner
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(PackageBulkActionResponse, Fixnum, Hash)>)

    PackageBulkActionResponse data, response status code and response headers



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/cloudsmith-api/api/recycle_bin_api.rb', line 100

def recycle_bin_recycle_bin_action_with_http_info(owner, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RecycleBinApi.recycle_bin_recycle_bin_action ...'
  end
  # verify the required parameter 'owner' is set
  if @api_client.config.client_side_validation && owner.nil?
    fail ArgumentError, "Missing the required parameter 'owner' when calling RecycleBinApi.recycle_bin_recycle_bin_action"
  end
  # resource path
  local_var_path = '/recycle-bin/{owner}/action/'.sub('{' + 'owner' + '}', owner.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(opts[:'data'])
  auth_names = ['apikey', 'basic']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PackageBulkActionResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RecycleBinApi#recycle_bin_recycle_bin_action\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end