Class: CloudsmithApi::ReposApi
- Inherits:
-
Object
- Object
- CloudsmithApi::ReposApi
- Defined in:
- lib/cloudsmith-api/api/repos_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ReposApi
constructor
A new instance of ReposApi.
-
#repos_all_list(opts = {}) ⇒ Array<Repository>
Get a list of all repositories associated with current user.
-
#repos_all_list_with_http_info(opts = {}) ⇒ Array<(Array<Repository>, Fixnum, Hash)>
Get a list of all repositories associated with current user.
-
#repos_create(owner, opts = {}) ⇒ RepositoryCreate
Create a new repository in a given namespace.
-
#repos_create_with_http_info(owner, opts = {}) ⇒ Array<(RepositoryCreate, Fixnum, Hash)>
Create a new repository in a given namespace.
-
#repos_delete(owner, identifier, opts = {}) ⇒ nil
Delete a repository in a given namespace.
-
#repos_delete_with_http_info(owner, identifier, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Delete a repository in a given namespace.
-
#repos_gpg_create(owner, identifier, opts = {}) ⇒ RepositoryGpgKey
Set the active GPG key for the Repository.
-
#repos_gpg_create_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryGpgKey, Fixnum, Hash)>
Set the active GPG key for the Repository.
-
#repos_gpg_list(owner, identifier, opts = {}) ⇒ RepositoryGpgKey
Retrieve the active GPG key for the Repository.
-
#repos_gpg_list_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryGpgKey, Fixnum, Hash)>
Retrieve the active GPG key for the Repository.
-
#repos_gpg_regenerate(owner, identifier, opts = {}) ⇒ RepositoryGpgKey
Regenerate GPG Key for the Repository.
-
#repos_gpg_regenerate_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryGpgKey, Fixnum, Hash)>
Regenerate GPG Key for the Repository.
-
#repos_list(owner, opts = {}) ⇒ Array<Repository>
Get a list of all repositories within a namespace.
-
#repos_list_with_http_info(owner, opts = {}) ⇒ Array<(Array<Repository>, Fixnum, Hash)>
Get a list of all repositories within a namespace.
-
#repos_partial_update(owner, identifier, opts = {}) ⇒ Repository
Update details about a repository in a given namespace.
-
#repos_partial_update_with_http_info(owner, identifier, opts = {}) ⇒ Array<(Repository, Fixnum, Hash)>
Update details about a repository in a given namespace.
-
#repos_privileges_list(owner, identifier, opts = {}) ⇒ RepositoryPrivilegeInput
List all explicity created privileges for the repository.
-
#repos_privileges_list_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryPrivilegeInput, Fixnum, Hash)>
List all explicity created privileges for the repository.
-
#repos_privileges_partial_update(owner, identifier, opts = {}) ⇒ nil
Modify privileges for the repository.
-
#repos_privileges_partial_update_with_http_info(owner, identifier, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Modify privileges for the repository.
-
#repos_privileges_update(owner, identifier, opts = {}) ⇒ nil
Replace all existing repository privileges with those specified.
-
#repos_privileges_update_with_http_info(owner, identifier, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Replace all existing repository privileges with those specified.
-
#repos_read(owner, identifier, opts = {}) ⇒ Repository
Get a specific repository.
-
#repos_read_with_http_info(owner, identifier, opts = {}) ⇒ Array<(Repository, Fixnum, Hash)>
Get a specific repository.
-
#repos_rsa_create(owner, identifier, opts = {}) ⇒ RepositoryRsaKey
Set the active RSA key for the Repository.
-
#repos_rsa_create_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryRsaKey, Fixnum, Hash)>
Set the active RSA key for the Repository.
-
#repos_rsa_list(owner, identifier, opts = {}) ⇒ RepositoryRsaKey
Retrieve the active RSA key for the Repository.
-
#repos_rsa_list_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryRsaKey, Fixnum, Hash)>
Retrieve the active RSA key for the Repository.
-
#repos_rsa_regenerate(owner, identifier, opts = {}) ⇒ RepositoryRsaKey
Regenerate RSA Key for the Repository.
-
#repos_rsa_regenerate_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryRsaKey, Fixnum, Hash)>
Regenerate RSA Key for the Repository.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ReposApi
Returns a new instance of ReposApi.
19 20 21 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#repos_all_list(opts = {}) ⇒ Array<Repository>
Get a list of all repositories associated with current user. Get a list of all repositories associated with current user.
28 29 30 31 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 28 def repos_all_list(opts = {}) data, _status_code, _headers = repos_all_list_with_http_info(opts) data end |
#repos_all_list_with_http_info(opts = {}) ⇒ Array<(Array<Repository>, Fixnum, Hash)>
Get a list of all repositories associated with current user. Get a list of all repositories associated with current user.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 39 def repos_all_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_all_list ...' end # resource path local_var_path = '/repos/' # query parameters query_params = {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Array<Repository>') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_all_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_create(owner, opts = {}) ⇒ RepositoryCreate
Create a new repository in a given namespace. Create a new repository in a given namespace.
78 79 80 81 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 78 def repos_create(owner, opts = {}) data, _status_code, _headers = repos_create_with_http_info(owner, opts) data end |
#repos_create_with_http_info(owner, opts = {}) ⇒ Array<(RepositoryCreate, Fixnum, Hash)>
Create a new repository in a given namespace. Create a new repository in a given namespace.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 89 def repos_create_with_http_info(owner, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_create ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_create" end # resource path local_var_path = '/repos/{owner}/'.sub('{' + 'owner' + '}', owner.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'data']) auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'RepositoryCreate') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_delete(owner, identifier, opts = {}) ⇒ nil
Delete a repository in a given namespace. Delete a repository in a given namespace.
132 133 134 135 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 132 def repos_delete(owner, identifier, opts = {}) repos_delete_with_http_info(owner, identifier, opts) nil end |
#repos_delete_with_http_info(owner, identifier, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Delete a repository in a given namespace. Delete a repository in a given namespace.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 143 def repos_delete_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_delete ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_delete" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_delete" end # resource path local_var_path = '/repos/{owner}/{identifier}/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names) if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_gpg_create(owner, identifier, opts = {}) ⇒ RepositoryGpgKey
Set the active GPG key for the Repository. Set the active GPG key for the Repository.
188 189 190 191 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 188 def repos_gpg_create(owner, identifier, opts = {}) data, _status_code, _headers = repos_gpg_create_with_http_info(owner, identifier, opts) data end |
#repos_gpg_create_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryGpgKey, Fixnum, Hash)>
Set the active GPG key for the Repository. Set the active GPG key for the Repository.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 200 def repos_gpg_create_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_gpg_create ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_gpg_create" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_gpg_create" end # resource path local_var_path = '/repos/{owner}/{identifier}/gpg/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'data']) auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'RepositoryGpgKey') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_gpg_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_gpg_list(owner, identifier, opts = {}) ⇒ RepositoryGpgKey
Retrieve the active GPG key for the Repository. Retrieve the active GPG key for the Repository.
247 248 249 250 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 247 def repos_gpg_list(owner, identifier, opts = {}) data, _status_code, _headers = repos_gpg_list_with_http_info(owner, identifier, opts) data end |
#repos_gpg_list_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryGpgKey, Fixnum, Hash)>
Retrieve the active GPG key for the Repository. Retrieve the active GPG key for the Repository.
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 258 def repos_gpg_list_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_gpg_list ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_gpg_list" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_gpg_list" end # resource path local_var_path = '/repos/{owner}/{identifier}/gpg/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'RepositoryGpgKey') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_gpg_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_gpg_regenerate(owner, identifier, opts = {}) ⇒ RepositoryGpgKey
Regenerate GPG Key for the Repository. Regenerate GPG Key for the Repository.
303 304 305 306 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 303 def repos_gpg_regenerate(owner, identifier, opts = {}) data, _status_code, _headers = repos_gpg_regenerate_with_http_info(owner, identifier, opts) data end |
#repos_gpg_regenerate_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryGpgKey, Fixnum, Hash)>
Regenerate GPG Key for the Repository. Regenerate GPG Key for the Repository.
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 314 def repos_gpg_regenerate_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_gpg_regenerate ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_gpg_regenerate" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_gpg_regenerate" end # resource path local_var_path = '/repos/{owner}/{identifier}/gpg/regenerate/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'RepositoryGpgKey') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_gpg_regenerate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_list(owner, opts = {}) ⇒ Array<Repository>
Get a list of all repositories within a namespace. Get a list of all repositories within a namespace.
360 361 362 363 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 360 def repos_list(owner, opts = {}) data, _status_code, _headers = repos_list_with_http_info(owner, opts) data end |
#repos_list_with_http_info(owner, opts = {}) ⇒ Array<(Array<Repository>, Fixnum, Hash)>
Get a list of all repositories within a namespace. Get a list of all repositories within a namespace.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 372 def repos_list_with_http_info(owner, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_list ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_list" end # resource path local_var_path = '/repos/{owner}/'.sub('{' + 'owner' + '}', owner.to_s) # query parameters query_params = {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Array<Repository>') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_partial_update(owner, identifier, opts = {}) ⇒ Repository
Update details about a repository in a given namespace. Update details about a repository in a given namespace.
416 417 418 419 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 416 def repos_partial_update(owner, identifier, opts = {}) data, _status_code, _headers = repos_partial_update_with_http_info(owner, identifier, opts) data end |
#repos_partial_update_with_http_info(owner, identifier, opts = {}) ⇒ Array<(Repository, Fixnum, Hash)>
Update details about a repository in a given namespace. Update details about a repository in a given namespace.
428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 428 def repos_partial_update_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_partial_update ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_partial_update" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_partial_update" end # resource path local_var_path = '/repos/{owner}/{identifier}/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'data']) auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Repository') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_privileges_list(owner, identifier, opts = {}) ⇒ RepositoryPrivilegeInput
List all explicity created privileges for the repository. List all explicity created privileges for the repository.
477 478 479 480 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 477 def repos_privileges_list(owner, identifier, opts = {}) data, _status_code, _headers = repos_privileges_list_with_http_info(owner, identifier, opts) data end |
#repos_privileges_list_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryPrivilegeInput, Fixnum, Hash)>
List all explicity created privileges for the repository. List all explicity created privileges for the repository.
490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 490 def repos_privileges_list_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_privileges_list ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_privileges_list" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_privileges_list" end # resource path local_var_path = '/repos/{owner}/{identifier}/privileges'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'RepositoryPrivilegeInput') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_privileges_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_privileges_partial_update(owner, identifier, opts = {}) ⇒ nil
Modify privileges for the repository. Modify privileges for the repository.
538 539 540 541 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 538 def repos_privileges_partial_update(owner, identifier, opts = {}) repos_privileges_partial_update_with_http_info(owner, identifier, opts) nil end |
#repos_privileges_partial_update_with_http_info(owner, identifier, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Modify privileges for the repository. Modify privileges for the repository.
550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 550 def repos_privileges_partial_update_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_privileges_partial_update ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_privileges_partial_update" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_privileges_partial_update" end # resource path local_var_path = '/repos/{owner}/{identifier}/privileges'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'data']) auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names) if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_privileges_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_privileges_update(owner, identifier, opts = {}) ⇒ nil
Replace all existing repository privileges with those specified. Replace all existing repository privileges with those specified.
597 598 599 600 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 597 def repos_privileges_update(owner, identifier, opts = {}) repos_privileges_update_with_http_info(owner, identifier, opts) nil end |
#repos_privileges_update_with_http_info(owner, identifier, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Replace all existing repository privileges with those specified. Replace all existing repository privileges with those specified.
609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 609 def repos_privileges_update_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_privileges_update ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_privileges_update" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_privileges_update" end # resource path local_var_path = '/repos/{owner}/{identifier}/privileges'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'data']) auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names) if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_privileges_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_read(owner, identifier, opts = {}) ⇒ Repository
Get a specific repository. Get a specific repository.
655 656 657 658 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 655 def repos_read(owner, identifier, opts = {}) data, _status_code, _headers = repos_read_with_http_info(owner, identifier, opts) data end |
#repos_read_with_http_info(owner, identifier, opts = {}) ⇒ Array<(Repository, Fixnum, Hash)>
Get a specific repository. Get a specific repository.
666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 666 def repos_read_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_read ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_read" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_read" end # resource path local_var_path = '/repos/{owner}/{identifier}/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Repository') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_rsa_create(owner, identifier, opts = {}) ⇒ RepositoryRsaKey
Set the active RSA key for the Repository. Set the active RSA key for the Repository.
712 713 714 715 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 712 def repos_rsa_create(owner, identifier, opts = {}) data, _status_code, _headers = repos_rsa_create_with_http_info(owner, identifier, opts) data end |
#repos_rsa_create_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryRsaKey, Fixnum, Hash)>
Set the active RSA key for the Repository. Set the active RSA key for the Repository.
724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 724 def repos_rsa_create_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_rsa_create ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_rsa_create" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_rsa_create" end # resource path local_var_path = '/repos/{owner}/{identifier}/rsa/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'data']) auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'RepositoryRsaKey') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_rsa_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_rsa_list(owner, identifier, opts = {}) ⇒ RepositoryRsaKey
Retrieve the active RSA key for the Repository. Retrieve the active RSA key for the Repository.
771 772 773 774 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 771 def repos_rsa_list(owner, identifier, opts = {}) data, _status_code, _headers = repos_rsa_list_with_http_info(owner, identifier, opts) data end |
#repos_rsa_list_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryRsaKey, Fixnum, Hash)>
Retrieve the active RSA key for the Repository. Retrieve the active RSA key for the Repository.
782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 782 def repos_rsa_list_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_rsa_list ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_rsa_list" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_rsa_list" end # resource path local_var_path = '/repos/{owner}/{identifier}/rsa/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'RepositoryRsaKey') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_rsa_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_rsa_regenerate(owner, identifier, opts = {}) ⇒ RepositoryRsaKey
Regenerate RSA Key for the Repository. Regenerate RSA Key for the Repository.
827 828 829 830 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 827 def repos_rsa_regenerate(owner, identifier, opts = {}) data, _status_code, _headers = repos_rsa_regenerate_with_http_info(owner, identifier, opts) data end |
#repos_rsa_regenerate_with_http_info(owner, identifier, opts = {}) ⇒ Array<(RepositoryRsaKey, Fixnum, Hash)>
Regenerate RSA Key for the Repository. Regenerate RSA Key for the Repository.
838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 838 def repos_rsa_regenerate_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_rsa_regenerate ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_rsa_regenerate" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_rsa_regenerate" end # resource path local_var_path = '/repos/{owner}/{identifier}/rsa/regenerate/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'RepositoryRsaKey') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_rsa_regenerate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |