Class: CloudsmithApi::RpmPackageUpload
- Inherits:
-
Object
- Object
- CloudsmithApi::RpmPackageUpload
- Defined in:
- lib/cloudsmith-api/models/rpm_package_upload.rb
Instance Attribute Summary collapse
-
#architectures ⇒ Object
Returns the value of attribute architectures.
-
#cdn_url ⇒ Object
Returns the value of attribute cdn_url.
-
#checksum_md5 ⇒ Object
Returns the value of attribute checksum_md5.
-
#checksum_sha1 ⇒ Object
Returns the value of attribute checksum_sha1.
-
#checksum_sha256 ⇒ Object
Returns the value of attribute checksum_sha256.
-
#checksum_sha512 ⇒ Object
Returns the value of attribute checksum_sha512.
-
#description ⇒ Object
A textual description of this package.
-
#distro ⇒ Object
Returns the value of attribute distro.
-
#distro_version ⇒ Object
Returns the value of attribute distro_version.
-
#downloads ⇒ Object
Returns the value of attribute downloads.
-
#epoch ⇒ Object
The epoch of the package version (if any).
-
#extension ⇒ Object
Returns the value of attribute extension.
-
#filename ⇒ Object
Returns the value of attribute filename.
-
#files ⇒ Object
Returns the value of attribute files.
-
#format ⇒ Object
Returns the value of attribute format.
-
#format_url ⇒ Object
Returns the value of attribute format_url.
-
#is_sync_awaiting ⇒ Object
Returns the value of attribute is_sync_awaiting.
-
#is_sync_completed ⇒ Object
Returns the value of attribute is_sync_completed.
-
#is_sync_failed ⇒ Object
Returns the value of attribute is_sync_failed.
-
#is_sync_in_flight ⇒ Object
Returns the value of attribute is_sync_in_flight.
-
#is_sync_in_progress ⇒ Object
Returns the value of attribute is_sync_in_progress.
-
#license ⇒ Object
The license of this package.
-
#name ⇒ Object
The name of this package.
-
#namespace ⇒ Object
Returns the value of attribute namespace.
-
#namespace_url ⇒ Object
Returns the value of attribute namespace_url.
-
#num_files ⇒ Object
Returns the value of attribute num_files.
-
#package_type ⇒ Object
The type of package contents.
-
#release ⇒ Object
The release of the package version (if any).
-
#repository ⇒ Object
Returns the value of attribute repository.
-
#repository_url ⇒ Object
Returns the value of attribute repository_url.
-
#self_html_url ⇒ Object
Returns the value of attribute self_html_url.
-
#self_url ⇒ Object
Returns the value of attribute self_url.
-
#size ⇒ Object
The calculated size of the package.
-
#slug ⇒ Object
Returns the value of attribute slug.
-
#slug_perm ⇒ Object
Returns the value of attribute slug_perm.
-
#stage ⇒ Object
The synchronisation (in progress) stage of the package.
-
#stage_str ⇒ Object
Returns the value of attribute stage_str.
-
#stage_updated_at ⇒ Object
The datetime the package stage was updated at.
-
#status ⇒ Object
The synchronisation status of the package.
-
#status_str ⇒ Object
Returns the value of attribute status_str.
-
#status_updated_at ⇒ Object
The datetime the package status was updated at.
-
#status_url ⇒ Object
Returns the value of attribute status_url.
-
#subtype ⇒ Object
Returns the value of attribute subtype.
-
#summary ⇒ Object
A one-liner synopsis of this package.
-
#sync_finished_at ⇒ Object
The datetime the package sync was finished at.
-
#sync_progress ⇒ Object
Synchronisation progress (from 0-100).
-
#type_display ⇒ Object
Returns the value of attribute type_display.
-
#uploaded_at ⇒ Object
The date this package was uploaded.
-
#uploader ⇒ Object
Returns the value of attribute uploader.
-
#uploader_url ⇒ Object
Returns the value of attribute uploader_url.
-
#version ⇒ Object
The version of this package.
-
#version_orig ⇒ Object
Returns the value of attribute version_orig.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RpmPackageUpload
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RpmPackageUpload
Initializes the object
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 293 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'status') self.status = attributes[:'status'] end if attributes.has_key?(:'stage_updated_at') self.stage_updated_at = attributes[:'stage_updated_at'] end if attributes.has_key?(:'checksum_sha512') self.checksum_sha512 = attributes[:'checksum_sha512'] end if attributes.has_key?(:'is_sync_failed') self.is_sync_failed = attributes[:'is_sync_failed'] end if attributes.has_key?(:'sync_finished_at') self.sync_finished_at = attributes[:'sync_finished_at'] end if attributes.has_key?(:'checksum_sha256') self.checksum_sha256 = attributes[:'checksum_sha256'] end if attributes.has_key?(:'repository_url') self.repository_url = attributes[:'repository_url'] end if attributes.has_key?(:'is_sync_in_progress') self.is_sync_in_progress = attributes[:'is_sync_in_progress'] end if attributes.has_key?(:'size') self.size = attributes[:'size'] end if attributes.has_key?(:'status_str') self.status_str = attributes[:'status_str'] end if attributes.has_key?(:'is_sync_awaiting') self.is_sync_awaiting = attributes[:'is_sync_awaiting'] end if attributes.has_key?(:'num_files') self.num_files = attributes[:'num_files'] end if attributes.has_key?(:'status_url') self.status_url = attributes[:'status_url'] end if attributes.has_key?(:'status_updated_at') self.status_updated_at = attributes[:'status_updated_at'] end if attributes.has_key?(:'namespace') self.namespace = attributes[:'namespace'] end if attributes.has_key?(:'distro_version') self.distro_version = attributes[:'distro_version'] end if attributes.has_key?(:'filename') self.filename = attributes[:'filename'] end if attributes.has_key?(:'sync_progress') self.sync_progress = attributes[:'sync_progress'] end if attributes.has_key?(:'epoch') self.epoch = attributes[:'epoch'] end if attributes.has_key?(:'version') self.version = attributes[:'version'] end if attributes.has_key?(:'is_sync_in_flight') self.is_sync_in_flight = attributes[:'is_sync_in_flight'] end if attributes.has_key?(:'namespace_url') self.namespace_url = attributes[:'namespace_url'] end if attributes.has_key?(:'slug_perm') self.slug_perm = attributes[:'slug_perm'] end if attributes.has_key?(:'uploader_url') self.uploader_url = attributes[:'uploader_url'] end if attributes.has_key?(:'checksum_sha1') self.checksum_sha1 = attributes[:'checksum_sha1'] end if attributes.has_key?(:'distro') self.distro = attributes[:'distro'] end if attributes.has_key?(:'files') if (value = attributes[:'files']).is_a?(Array) self.files = value end end if attributes.has_key?(:'cdn_url') self.cdn_url = attributes[:'cdn_url'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'repository') self.repository = attributes[:'repository'] end if attributes.has_key?(:'format') self.format = attributes[:'format'] end if attributes.has_key?(:'is_sync_completed') self.is_sync_completed = attributes[:'is_sync_completed'] end if attributes.has_key?(:'downloads') self.downloads = attributes[:'downloads'] end if attributes.has_key?(:'version_orig') self.version_orig = attributes[:'version_orig'] end if attributes.has_key?(:'architectures') if (value = attributes[:'architectures']).is_a?(Array) self.architectures = value end end if attributes.has_key?(:'uploader') self.uploader = attributes[:'uploader'] end if attributes.has_key?(:'self_html_url') self.self_html_url = attributes[:'self_html_url'] end if attributes.has_key?(:'stage') self.stage = attributes[:'stage'] end if attributes.has_key?(:'self_url') self.self_url = attributes[:'self_url'] end if attributes.has_key?(:'slug') self.slug = attributes[:'slug'] end if attributes.has_key?(:'uploaded_at') self.uploaded_at = attributes[:'uploaded_at'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'license') self.license = attributes[:'license'] end if attributes.has_key?(:'stage_str') self.stage_str = attributes[:'stage_str'] end if attributes.has_key?(:'package_type') self.package_type = attributes[:'package_type'] end if attributes.has_key?(:'summary') self.summary = attributes[:'summary'] end if attributes.has_key?(:'subtype') self.subtype = attributes[:'subtype'] end if attributes.has_key?(:'checksum_md5') self.checksum_md5 = attributes[:'checksum_md5'] end if attributes.has_key?(:'extension') self.extension = attributes[:'extension'] end if attributes.has_key?(:'release') self.release = attributes[:'release'] end if attributes.has_key?(:'type_display') self.type_display = attributes[:'type_display'] end if attributes.has_key?(:'format_url') self.format_url = attributes[:'format_url'] end end |
Instance Attribute Details
#architectures ⇒ Object
Returns the value of attribute architectures.
121 122 123 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 121 def architectures @architectures end |
#cdn_url ⇒ Object
Returns the value of attribute cdn_url.
100 101 102 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 100 def cdn_url @cdn_url end |
#checksum_md5 ⇒ Object
Returns the value of attribute checksum_md5.
160 161 162 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 160 def checksum_md5 @checksum_md5 end |
#checksum_sha1 ⇒ Object
Returns the value of attribute checksum_sha1.
91 92 93 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 91 def checksum_sha1 @checksum_sha1 end |
#checksum_sha256 ⇒ Object
Returns the value of attribute checksum_sha256.
34 35 36 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 34 def checksum_sha256 @checksum_sha256 end |
#checksum_sha512 ⇒ Object
Returns the value of attribute checksum_sha512.
25 26 27 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 25 def checksum_sha512 @checksum_sha512 end |
#description ⇒ Object
A textual description of this package.
103 104 105 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 103 def description @description end |
#distro ⇒ Object
Returns the value of attribute distro.
94 95 96 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 94 def distro @distro end |
#distro_version ⇒ Object
Returns the value of attribute distro_version.
64 65 66 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 64 def distro_version @distro_version end |
#downloads ⇒ Object
Returns the value of attribute downloads.
115 116 117 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 115 def downloads @downloads end |
#epoch ⇒ Object
The epoch of the package version (if any).
73 74 75 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 73 def epoch @epoch end |
#extension ⇒ Object
Returns the value of attribute extension.
163 164 165 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 163 def extension @extension end |
#filename ⇒ Object
Returns the value of attribute filename.
67 68 69 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 67 def filename @filename end |
#files ⇒ Object
Returns the value of attribute files.
97 98 99 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 97 def files @files end |
#format ⇒ Object
Returns the value of attribute format.
109 110 111 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 109 def format @format end |
#format_url ⇒ Object
Returns the value of attribute format_url.
172 173 174 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 172 def format_url @format_url end |
#is_sync_awaiting ⇒ Object
Returns the value of attribute is_sync_awaiting.
49 50 51 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 49 def is_sync_awaiting @is_sync_awaiting end |
#is_sync_completed ⇒ Object
Returns the value of attribute is_sync_completed.
112 113 114 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 112 def is_sync_completed @is_sync_completed end |
#is_sync_failed ⇒ Object
Returns the value of attribute is_sync_failed.
28 29 30 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 28 def is_sync_failed @is_sync_failed end |
#is_sync_in_flight ⇒ Object
Returns the value of attribute is_sync_in_flight.
79 80 81 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 79 def is_sync_in_flight @is_sync_in_flight end |
#is_sync_in_progress ⇒ Object
Returns the value of attribute is_sync_in_progress.
40 41 42 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 40 def is_sync_in_progress @is_sync_in_progress end |
#license ⇒ Object
The license of this package.
145 146 147 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 145 def license @license end |
#name ⇒ Object
The name of this package.
142 143 144 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 142 def name @name end |
#namespace ⇒ Object
Returns the value of attribute namespace.
61 62 63 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 61 def namespace @namespace end |
#namespace_url ⇒ Object
Returns the value of attribute namespace_url.
82 83 84 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 82 def namespace_url @namespace_url end |
#num_files ⇒ Object
Returns the value of attribute num_files.
52 53 54 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 52 def num_files @num_files end |
#package_type ⇒ Object
The type of package contents.
151 152 153 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 151 def package_type @package_type end |
#release ⇒ Object
The release of the package version (if any).
166 167 168 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 166 def release @release end |
#repository ⇒ Object
Returns the value of attribute repository.
106 107 108 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 106 def repository @repository end |
#repository_url ⇒ Object
Returns the value of attribute repository_url.
37 38 39 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 37 def repository_url @repository_url end |
#self_html_url ⇒ Object
Returns the value of attribute self_html_url.
127 128 129 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 127 def self_html_url @self_html_url end |
#self_url ⇒ Object
Returns the value of attribute self_url.
133 134 135 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 133 def self_url @self_url end |
#size ⇒ Object
The calculated size of the package.
43 44 45 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 43 def size @size end |
#slug ⇒ Object
Returns the value of attribute slug.
136 137 138 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 136 def slug @slug end |
#slug_perm ⇒ Object
Returns the value of attribute slug_perm.
85 86 87 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 85 def slug_perm @slug_perm end |
#stage ⇒ Object
The synchronisation (in progress) stage of the package.
130 131 132 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 130 def stage @stage end |
#stage_str ⇒ Object
Returns the value of attribute stage_str.
148 149 150 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 148 def stage_str @stage_str end |
#stage_updated_at ⇒ Object
The datetime the package stage was updated at.
22 23 24 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 22 def stage_updated_at @stage_updated_at end |
#status ⇒ Object
The synchronisation status of the package.
19 20 21 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 19 def status @status end |
#status_str ⇒ Object
Returns the value of attribute status_str.
46 47 48 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 46 def status_str @status_str end |
#status_updated_at ⇒ Object
The datetime the package status was updated at.
58 59 60 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 58 def status_updated_at @status_updated_at end |
#status_url ⇒ Object
Returns the value of attribute status_url.
55 56 57 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 55 def status_url @status_url end |
#subtype ⇒ Object
Returns the value of attribute subtype.
157 158 159 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 157 def subtype @subtype end |
#summary ⇒ Object
A one-liner synopsis of this package.
154 155 156 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 154 def summary @summary end |
#sync_finished_at ⇒ Object
The datetime the package sync was finished at.
31 32 33 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 31 def sync_finished_at @sync_finished_at end |
#sync_progress ⇒ Object
Synchronisation progress (from 0-100)
70 71 72 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 70 def sync_progress @sync_progress end |
#type_display ⇒ Object
Returns the value of attribute type_display.
169 170 171 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 169 def type_display @type_display end |
#uploaded_at ⇒ Object
The date this package was uploaded.
139 140 141 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 139 def uploaded_at @uploaded_at end |
#uploader ⇒ Object
Returns the value of attribute uploader.
124 125 126 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 124 def uploader @uploader end |
#uploader_url ⇒ Object
Returns the value of attribute uploader_url.
88 89 90 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 88 def uploader_url @uploader_url end |
#version ⇒ Object
The version of this package.
76 77 78 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 76 def version @version end |
#version_orig ⇒ Object
Returns the value of attribute version_orig.
118 119 120 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 118 def version_orig @version_orig end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 176 def self.attribute_map { :'status' => :'status', :'stage_updated_at' => :'stage_updated_at', :'checksum_sha512' => :'checksum_sha512', :'is_sync_failed' => :'is_sync_failed', :'sync_finished_at' => :'sync_finished_at', :'checksum_sha256' => :'checksum_sha256', :'repository_url' => :'repository_url', :'is_sync_in_progress' => :'is_sync_in_progress', :'size' => :'size', :'status_str' => :'status_str', :'is_sync_awaiting' => :'is_sync_awaiting', :'num_files' => :'num_files', :'status_url' => :'status_url', :'status_updated_at' => :'status_updated_at', :'namespace' => :'namespace', :'distro_version' => :'distro_version', :'filename' => :'filename', :'sync_progress' => :'sync_progress', :'epoch' => :'epoch', :'version' => :'version', :'is_sync_in_flight' => :'is_sync_in_flight', :'namespace_url' => :'namespace_url', :'slug_perm' => :'slug_perm', :'uploader_url' => :'uploader_url', :'checksum_sha1' => :'checksum_sha1', :'distro' => :'distro', :'files' => :'files', :'cdn_url' => :'cdn_url', :'description' => :'description', :'repository' => :'repository', :'format' => :'format', :'is_sync_completed' => :'is_sync_completed', :'downloads' => :'downloads', :'version_orig' => :'version_orig', :'architectures' => :'architectures', :'uploader' => :'uploader', :'self_html_url' => :'self_html_url', :'stage' => :'stage', :'self_url' => :'self_url', :'slug' => :'slug', :'uploaded_at' => :'uploaded_at', :'name' => :'name', :'license' => :'license', :'stage_str' => :'stage_str', :'package_type' => :'package_type', :'summary' => :'summary', :'subtype' => :'subtype', :'checksum_md5' => :'checksum_md5', :'extension' => :'extension', :'release' => :'release', :'type_display' => :'type_display', :'format_url' => :'format_url' } end |
.swagger_types ⇒ Object
Attribute type mapping.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 234 def self.swagger_types { :'status' => :'String', :'stage_updated_at' => :'String', :'checksum_sha512' => :'String', :'is_sync_failed' => :'BOOLEAN', :'sync_finished_at' => :'String', :'checksum_sha256' => :'String', :'repository_url' => :'String', :'is_sync_in_progress' => :'BOOLEAN', :'size' => :'Integer', :'status_str' => :'String', :'is_sync_awaiting' => :'BOOLEAN', :'num_files' => :'Integer', :'status_url' => :'String', :'status_updated_at' => :'String', :'namespace' => :'String', :'distro_version' => :'Object', :'filename' => :'String', :'sync_progress' => :'Integer', :'epoch' => :'Integer', :'version' => :'String', :'is_sync_in_flight' => :'BOOLEAN', :'namespace_url' => :'String', :'slug_perm' => :'String', :'uploader_url' => :'String', :'checksum_sha1' => :'String', :'distro' => :'Object', :'files' => :'Array<RpmPackageUploadFiles>', :'cdn_url' => :'String', :'description' => :'String', :'repository' => :'String', :'format' => :'String', :'is_sync_completed' => :'BOOLEAN', :'downloads' => :'String', :'version_orig' => :'String', :'architectures' => :'Array<RpmPackageUploadArchitectures>', :'uploader' => :'String', :'self_html_url' => :'String', :'stage' => :'String', :'self_url' => :'String', :'slug' => :'String', :'uploaded_at' => :'String', :'name' => :'String', :'license' => :'String', :'stage_str' => :'String', :'package_type' => :'String', :'summary' => :'String', :'subtype' => :'String', :'checksum_md5' => :'String', :'extension' => :'String', :'release' => :'String', :'type_display' => :'String', :'format_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 528 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && stage_updated_at == o.stage_updated_at && checksum_sha512 == o.checksum_sha512 && is_sync_failed == o.is_sync_failed && sync_finished_at == o.sync_finished_at && checksum_sha256 == o.checksum_sha256 && repository_url == o.repository_url && is_sync_in_progress == o.is_sync_in_progress && size == o.size && status_str == o.status_str && is_sync_awaiting == o.is_sync_awaiting && num_files == o.num_files && status_url == o.status_url && status_updated_at == o.status_updated_at && namespace == o.namespace && distro_version == o.distro_version && filename == o.filename && sync_progress == o.sync_progress && epoch == o.epoch && version == o.version && is_sync_in_flight == o.is_sync_in_flight && namespace_url == o.namespace_url && slug_perm == o.slug_perm && uploader_url == o.uploader_url && checksum_sha1 == o.checksum_sha1 && distro == o.distro && files == o.files && cdn_url == o.cdn_url && description == o.description && repository == o.repository && format == o.format && is_sync_completed == o.is_sync_completed && downloads == o.downloads && version_orig == o.version_orig && architectures == o.architectures && uploader == o.uploader && self_html_url == o.self_html_url && stage == o.stage && self_url == o.self_url && slug == o.slug && uploaded_at == o.uploaded_at && name == o.name && license == o.license && stage_str == o.stage_str && package_type == o.package_type && summary == o.summary && subtype == o.subtype && checksum_md5 == o.checksum_md5 && extension == o.extension && release == o.release && type_display == o.type_display && format_url == o.format_url end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 621 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CloudsmithApi.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
687 688 689 690 691 692 693 694 695 696 697 698 699 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 687 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 600 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
587 588 589 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 587 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
593 594 595 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 593 def hash [status, stage_updated_at, checksum_sha512, is_sync_failed, sync_finished_at, checksum_sha256, repository_url, is_sync_in_progress, size, status_str, is_sync_awaiting, num_files, status_url, status_updated_at, namespace, distro_version, filename, sync_progress, epoch, version, is_sync_in_flight, namespace_url, slug_perm, uploader_url, checksum_sha1, distro, files, cdn_url, description, repository, format, is_sync_completed, downloads, version_orig, architectures, uploader, self_html_url, stage, self_url, slug, uploaded_at, name, license, stage_str, package_type, summary, subtype, checksum_md5, extension, release, type_display, format_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
515 516 517 518 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 515 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
667 668 669 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 667 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
673 674 675 676 677 678 679 680 681 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 673 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
661 662 663 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 661 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
522 523 524 |
# File 'lib/cloudsmith-api/models/rpm_package_upload.rb', line 522 def valid? return true end |