Class: CloudsmithApi::RpmUpstream

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudsmith-api/models/rpm_upstream.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RpmUpstream

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 209

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'auth_mode')
    self.auth_mode = attributes[:'auth_mode']
  else
    self.auth_mode = 'None'
  end

  if attributes.has_key?(:'auth_secret')
    self.auth_secret = attributes[:'auth_secret']
  end

  if attributes.has_key?(:'auth_username')
    self.auth_username = attributes[:'auth_username']
  end

  if attributes.has_key?(:'available')
    self.available = attributes[:'available']
  end

  if attributes.has_key?(:'can_reindex')
    self.can_reindex = attributes[:'can_reindex']
  end

  if attributes.has_key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.has_key?(:'disable_reason')
    self.disable_reason = attributes[:'disable_reason']
  else
    self.disable_reason = 'N/A'
  end

  if attributes.has_key?(:'disable_reason_text')
    self.disable_reason_text = attributes[:'disable_reason_text']
  end

  if attributes.has_key?(:'distro_version')
    self.distro_version = attributes[:'distro_version']
  end

  if attributes.has_key?(:'extra_header_1')
    self.extra_header_1 = attributes[:'extra_header_1']
  end

  if attributes.has_key?(:'extra_header_2')
    self.extra_header_2 = attributes[:'extra_header_2']
  end

  if attributes.has_key?(:'extra_value_1')
    self.extra_value_1 = attributes[:'extra_value_1']
  end

  if attributes.has_key?(:'extra_value_2')
    self.extra_value_2 = attributes[:'extra_value_2']
  end

  if attributes.has_key?(:'gpg_key_fingerprint_short')
    self.gpg_key_fingerprint_short = attributes[:'gpg_key_fingerprint_short']
  end

  if attributes.has_key?(:'gpg_key_inline')
    self.gpg_key_inline = attributes[:'gpg_key_inline']
  end

  if attributes.has_key?(:'gpg_key_url')
    self.gpg_key_url = attributes[:'gpg_key_url']
  end

  if attributes.has_key?(:'gpg_verification')
    self.gpg_verification = attributes[:'gpg_verification']
  else
    self.gpg_verification = 'Allow All'
  end

  if attributes.has_key?(:'has_failed_signature_verification')
    self.has_failed_signature_verification = attributes[:'has_failed_signature_verification']
  end

  if attributes.has_key?(:'include_sources')
    self.include_sources = attributes[:'include_sources']
  end

  if attributes.has_key?(:'index_package_count')
    self.index_package_count = attributes[:'index_package_count']
  end

  if attributes.has_key?(:'index_status')
    self.index_status = attributes[:'index_status']
  end

  if attributes.has_key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.has_key?(:'last_indexed')
    self.last_indexed = attributes[:'last_indexed']
  end

  if attributes.has_key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = 'Proxy Only'
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'pending_validation')
    self.pending_validation = attributes[:'pending_validation']
  end

  if attributes.has_key?(:'priority')
    self.priority = attributes[:'priority']
  end

  if attributes.has_key?(:'slug_perm')
    self.slug_perm = attributes[:'slug_perm']
  end

  if attributes.has_key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.has_key?(:'upstream_url')
    self.upstream_url = attributes[:'upstream_url']
  end

  if attributes.has_key?(:'verification_status')
    self.verification_status = attributes[:'verification_status']
  else
    self.verification_status = 'Unknown'
  end

  if attributes.has_key?(:'verify_ssl')
    self.verify_ssl = attributes[:'verify_ssl']
  end
end

Instance Attribute Details

#auth_modeObject

The authentication mode to use when accessing this upstream.



18
19
20
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 18

def auth_mode
  @auth_mode
end

#auth_secretObject

Secret to provide with requests to upstream.



21
22
23
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 21

def auth_secret
  @auth_secret
end

#auth_usernameObject

Username to provide with requests to upstream.



24
25
26
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 24

def auth_username
  @auth_username
end

#availableObject

Whether the upstream is available for use.



27
28
29
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 27

def available
  @available
end

#can_reindexObject

Whether the upstream can be reindexed.



30
31
32
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 30

def can_reindex
  @can_reindex
end

#created_atObject

The datetime the upstream source was created.



33
34
35
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 33

def created_at
  @created_at
end

#disable_reasonObject

Returns the value of attribute disable_reason.



35
36
37
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 35

def disable_reason
  @disable_reason
end

#disable_reason_textObject

Human-readable explanation of why this upstream is disabled



38
39
40
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 38

def disable_reason_text
  @disable_reason_text
end

#distro_versionObject

The distribution version that packages found on this upstream will be associated with.



41
42
43
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 41

def distro_version
  @distro_version
end

#extra_header_1Object

The key for extra header #1 to send to upstream.



44
45
46
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 44

def extra_header_1
  @extra_header_1
end

#extra_header_2Object

The key for extra header #2 to send to upstream.



47
48
49
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 47

def extra_header_2
  @extra_header_2
end

#extra_value_1Object

The value for extra header #1 to send to upstream. This is stored as plaintext, and is NOT encrypted.



50
51
52
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 50

def extra_value_1
  @extra_value_1
end

#extra_value_2Object

The value for extra header #2 to send to upstream. This is stored as plaintext, and is NOT encrypted.



53
54
55
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 53

def extra_value_2
  @extra_value_2
end

#gpg_key_fingerprint_shortObject

Returns the value of attribute gpg_key_fingerprint_short.



55
56
57
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 55

def gpg_key_fingerprint_short
  @gpg_key_fingerprint_short
end

#gpg_key_inlineObject

A public GPG key to associate with packages found on this upstream. When using the Cloudsmith setup script, this GPG key will be automatically imported on your deployment machines to allow upstream packages to validate and install.



58
59
60
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 58

def gpg_key_inline
  @gpg_key_inline
end

#gpg_key_urlObject

When provided, Cloudsmith will fetch, validate, and associate a public GPG key found at the provided URL. When using the Cloudsmith setup script, this GPG key will be automatically imported on your deployment machines to allow upstream packages to validate and install.



61
62
63
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 61

def gpg_key_url
  @gpg_key_url
end

#gpg_verificationObject

The GPG signature verification mode for this upstream.



64
65
66
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 64

def gpg_verification
  @gpg_verification
end

#has_failed_signature_verificationObject

Whether the upstream has failed signature verification.



67
68
69
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 67

def has_failed_signature_verification
  @has_failed_signature_verification
end

#include_sourcesObject

When checked, source packages will be available from this upstream.



70
71
72
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 70

def include_sources
  @include_sources
end

#index_package_countObject

The number of packages available in this upstream source



73
74
75
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 73

def index_package_count
  @index_package_count
end

#index_statusObject

The current indexing status of this upstream source



76
77
78
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 76

def index_status
  @index_status
end

#is_activeObject

Whether or not this upstream is active and ready for requests.



79
80
81
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 79

def is_active
  @is_active
end

#last_indexedObject

The last time this upstream source was indexed



82
83
84
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 82

def last_indexed
  @last_indexed
end

#modeObject

The mode that this upstream should operate in. Upstream sources can be used to proxy resolved packages, as well as operate in a proxy/cache or cache only mode.



85
86
87
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 85

def mode
  @mode
end

#nameObject

A descriptive name for this upstream source. A shortened version of this name will be used for tagging cached packages retrieved from this upstream.



88
89
90
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 88

def name
  @name
end

#pending_validationObject

When true, this upstream source is pending validation.



91
92
93
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 91

def pending_validation
  @pending_validation
end

#priorityObject

Upstream sources are selected for resolving requests by sequential order (1..n), followed by creation date.



94
95
96
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 94

def priority
  @priority
end

#slug_permObject

Returns the value of attribute slug_perm.



96
97
98
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 96

def slug_perm
  @slug_perm
end

#updated_atObject

Returns the value of attribute updated_at.



98
99
100
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 98

def updated_at
  @updated_at
end

#upstream_urlObject

The URL for this upstream source. This must be a fully qualified URL including any path elements required to reach the root of the repository.



101
102
103
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 101

def upstream_url
  @upstream_url
end

#verification_statusObject

The signature verification status for this upstream.



104
105
106
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 104

def verification_status
  @verification_status
end

#verify_sslObject

If enabled, SSL certificates are verified when requests are made to this upstream. It’s recommended to leave this enabled for all public sources to help mitigate Man-In-The-Middle (MITM) attacks. Please note this only applies to HTTPS upstreams.



107
108
109
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 107

def verify_ssl
  @verify_ssl
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 132

def self.attribute_map
  {
    :'auth_mode' => :'auth_mode',
    :'auth_secret' => :'auth_secret',
    :'auth_username' => :'auth_username',
    :'available' => :'available',
    :'can_reindex' => :'can_reindex',
    :'created_at' => :'created_at',
    :'disable_reason' => :'disable_reason',
    :'disable_reason_text' => :'disable_reason_text',
    :'distro_version' => :'distro_version',
    :'extra_header_1' => :'extra_header_1',
    :'extra_header_2' => :'extra_header_2',
    :'extra_value_1' => :'extra_value_1',
    :'extra_value_2' => :'extra_value_2',
    :'gpg_key_fingerprint_short' => :'gpg_key_fingerprint_short',
    :'gpg_key_inline' => :'gpg_key_inline',
    :'gpg_key_url' => :'gpg_key_url',
    :'gpg_verification' => :'gpg_verification',
    :'has_failed_signature_verification' => :'has_failed_signature_verification',
    :'include_sources' => :'include_sources',
    :'index_package_count' => :'index_package_count',
    :'index_status' => :'index_status',
    :'is_active' => :'is_active',
    :'last_indexed' => :'last_indexed',
    :'mode' => :'mode',
    :'name' => :'name',
    :'pending_validation' => :'pending_validation',
    :'priority' => :'priority',
    :'slug_perm' => :'slug_perm',
    :'updated_at' => :'updated_at',
    :'upstream_url' => :'upstream_url',
    :'verification_status' => :'verification_status',
    :'verify_ssl' => :'verify_ssl'
  }
end

.swagger_typesObject

Attribute type mapping.



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 170

def self.swagger_types
  {
    :'auth_mode' => :'String',
    :'auth_secret' => :'String',
    :'auth_username' => :'String',
    :'available' => :'BOOLEAN',
    :'can_reindex' => :'BOOLEAN',
    :'created_at' => :'DateTime',
    :'disable_reason' => :'String',
    :'disable_reason_text' => :'String',
    :'distro_version' => :'String',
    :'extra_header_1' => :'String',
    :'extra_header_2' => :'String',
    :'extra_value_1' => :'String',
    :'extra_value_2' => :'String',
    :'gpg_key_fingerprint_short' => :'String',
    :'gpg_key_inline' => :'String',
    :'gpg_key_url' => :'String',
    :'gpg_verification' => :'String',
    :'has_failed_signature_verification' => :'BOOLEAN',
    :'include_sources' => :'BOOLEAN',
    :'index_package_count' => :'Integer',
    :'index_status' => :'String',
    :'is_active' => :'BOOLEAN',
    :'last_indexed' => :'String',
    :'mode' => :'String',
    :'name' => :'String',
    :'pending_validation' => :'BOOLEAN',
    :'priority' => :'Integer',
    :'slug_perm' => :'String',
    :'updated_at' => :'DateTime',
    :'upstream_url' => :'String',
    :'verification_status' => :'String',
    :'verify_ssl' => :'BOOLEAN'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 444

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auth_mode == o.auth_mode &&
      auth_secret == o.auth_secret &&
      auth_username == o.auth_username &&
      available == o.available &&
      can_reindex == o.can_reindex &&
      created_at == o.created_at &&
      disable_reason == o.disable_reason &&
      disable_reason_text == o.disable_reason_text &&
      distro_version == o.distro_version &&
      extra_header_1 == o.extra_header_1 &&
      extra_header_2 == o.extra_header_2 &&
      extra_value_1 == o.extra_value_1 &&
      extra_value_2 == o.extra_value_2 &&
      gpg_key_fingerprint_short == o.gpg_key_fingerprint_short &&
      gpg_key_inline == o.gpg_key_inline &&
      gpg_key_url == o.gpg_key_url &&
      gpg_verification == o.gpg_verification &&
      has_failed_signature_verification == o.has_failed_signature_verification &&
      include_sources == o.include_sources &&
      index_package_count == o.index_package_count &&
      index_status == o.index_status &&
      is_active == o.is_active &&
      last_indexed == o.last_indexed &&
      mode == o.mode &&
      name == o.name &&
      pending_validation == o.pending_validation &&
      priority == o.priority &&
      slug_perm == o.slug_perm &&
      updated_at == o.updated_at &&
      upstream_url == o.upstream_url &&
      verification_status == o.verification_status &&
      verify_ssl == o.verify_ssl
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 517

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CloudsmithApi.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



583
584
585
586
587
588
589
590
591
592
593
594
595
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 583

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 496

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


483
484
485
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 483

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



489
490
491
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 489

def hash
  [auth_mode, auth_secret, auth_username, available, can_reindex, created_at, disable_reason, disable_reason_text, distro_version, extra_header_1, extra_header_2, extra_value_1, extra_value_2, gpg_key_fingerprint_short, gpg_key_inline, gpg_key_url, gpg_verification, has_failed_signature_verification, include_sources, index_package_count, index_status, is_active, last_indexed, mode, name, pending_validation, priority, slug_perm, updated_at, upstream_url, verification_status, verify_ssl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 356

def list_invalid_properties
  invalid_properties = Array.new
  if @distro_version.nil?
    invalid_properties.push('invalid value for "distro_version", distro_version cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @upstream_url.nil?
    invalid_properties.push('invalid value for "upstream_url", upstream_url cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



563
564
565
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 563

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



569
570
571
572
573
574
575
576
577
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 569

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



557
558
559
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 557

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/cloudsmith-api/models/rpm_upstream.rb', line 375

def valid?
  auth_mode_validator = EnumAttributeValidator.new('String', ['None', 'Username and Password'])
  return false unless auth_mode_validator.valid?(@auth_mode)
  disable_reason_validator = EnumAttributeValidator.new('String', ['N/A', 'Upstream points to its own repository', 'Missing upstream source', 'Upstream was disabled by request of user'])
  return false unless disable_reason_validator.valid?(@disable_reason)
  return false if @distro_version.nil?
  gpg_verification_validator = EnumAttributeValidator.new('String', ['Allow All', 'Warn on Invalid', 'Reject Invalid'])
  return false unless gpg_verification_validator.valid?(@gpg_verification)
  mode_validator = EnumAttributeValidator.new('String', ['Proxy Only', 'Cache and Proxy'])
  return false unless mode_validator.valid?(@mode)
  return false if @name.nil?
  return false if @upstream_url.nil?
  verification_status_validator = EnumAttributeValidator.new('String', ['Unknown', 'Invalid', 'Valid', 'Invalid (No Key)'])
  return false unless verification_status_validator.valid?(@verification_status)
  true
end