Class: CloudsmithApi::MavenPackageUploadRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudsmith-api/models/maven_package_upload_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MavenPackageUploadRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 113

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'artifact_id')
    self.artifact_id = attributes[:'artifact_id']
  end

  if attributes.has_key?(:'extra_files')
    if (value = attributes[:'extra_files']).is_a?(Array)
      self.extra_files = value
    end
  end

  if attributes.has_key?(:'group_id')
    self.group_id = attributes[:'group_id']
  end

  if attributes.has_key?(:'is_malware_detected')
    self.is_malware_detected = attributes[:'is_malware_detected']
  end

  if attributes.has_key?(:'ivy_file')
    self.ivy_file = attributes[:'ivy_file']
  end

  if attributes.has_key?(:'javadoc_file')
    self.javadoc_file = attributes[:'javadoc_file']
  end

  if attributes.has_key?(:'package_file')
    self.package_file = attributes[:'package_file']
  end

  if attributes.has_key?(:'packaging')
    self.packaging = attributes[:'packaging']
  end

  if attributes.has_key?(:'pom_file')
    self.pom_file = attributes[:'pom_file']
  end

  if attributes.has_key?(:'republish')
    self.republish = attributes[:'republish']
  end

  if attributes.has_key?(:'sbt_version')
    self.sbt_version = attributes[:'sbt_version']
  end

  if attributes.has_key?(:'scala_version')
    self.scala_version = attributes[:'scala_version']
  end

  if attributes.has_key?(:'sources_file')
    self.sources_file = attributes[:'sources_file']
  end

  if attributes.has_key?(:'tags')
    self.tags = attributes[:'tags']
  end

  if attributes.has_key?(:'tests_file')
    self.tests_file = attributes[:'tests_file']
  end

  if attributes.has_key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.has_key?(:'vulnerability_counts')
    self.vulnerability_counts = attributes[:'vulnerability_counts']
  end
end

Instance Attribute Details

#artifact_idObject

The ID of the artifact.



18
19
20
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 18

def artifact_id
  @artifact_id
end

#extra_filesObject

Extra files to include in the package. This can be a single file or multiple files.



21
22
23
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 21

def extra_files
  @extra_files
end

#group_idObject

Artifact's group ID.



24
25
26
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 24

def group_id
  @group_id
end

#is_malware_detectedObject

Whether the package has been detected as containing malware. Requires Ultra plan.



27
28
29
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 27

def is_malware_detected
  @is_malware_detected
end

#ivy_fileObject

The ivy file is an XML file describing the dependencies of the project.



30
31
32
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 30

def ivy_file
  @ivy_file
end

#javadoc_fileObject

Adds bundled Java documentation to the Maven package



33
34
35
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 33

def javadoc_file
  @javadoc_file
end

#package_fileObject

The primary file for the package.



36
37
38
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 36

def package_file
  @package_file
end

#packagingObject

Artifact's Maven packaging type.



39
40
41
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 39

def packaging
  @packaging
end

#pom_fileObject

The POM file is an XML file containing the Maven coordinates.



42
43
44
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 42

def pom_file
  @pom_file
end

#republishObject

If true, the uploaded package will overwrite any others with the same attributes (e.g. same version); otherwise, it will be flagged as a duplicate.



45
46
47
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 45

def republish
  @republish
end

#sbt_versionObject

Returns the value of attribute sbt_version.



47
48
49
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 47

def sbt_version
  @sbt_version
end

#scala_versionObject

Returns the value of attribute scala_version.



49
50
51
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 49

def scala_version
  @scala_version
end

#sources_fileObject

Adds bundled Java source code to the Maven package.



52
53
54
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 52

def sources_file
  @sources_file
end

#tagsObject

A comma-separated values list of tags to add to the package.



55
56
57
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 55

def tags
  @tags
end

#tests_fileObject

Adds bundled Java tests to the Maven package.



58
59
60
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 58

def tests_file
  @tests_file
end

#versionObject

The raw version for this package.



61
62
63
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 61

def version
  @version
end

#vulnerability_countsObject

Returns the value of attribute vulnerability_counts.



63
64
65
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 63

def vulnerability_counts
  @vulnerability_counts
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 66

def self.attribute_map
  {
    :'artifact_id' => :'artifact_id',
    :'extra_files' => :'extra_files',
    :'group_id' => :'group_id',
    :'is_malware_detected' => :'is_malware_detected',
    :'ivy_file' => :'ivy_file',
    :'javadoc_file' => :'javadoc_file',
    :'package_file' => :'package_file',
    :'packaging' => :'packaging',
    :'pom_file' => :'pom_file',
    :'republish' => :'republish',
    :'sbt_version' => :'sbt_version',
    :'scala_version' => :'scala_version',
    :'sources_file' => :'sources_file',
    :'tags' => :'tags',
    :'tests_file' => :'tests_file',
    :'version' => :'version',
    :'vulnerability_counts' => :'vulnerability_counts'
  }
end

.swagger_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 89

def self.swagger_types
  {
    :'artifact_id' => :'String',
    :'extra_files' => :'Array<String>',
    :'group_id' => :'String',
    :'is_malware_detected' => :'BOOLEAN',
    :'ivy_file' => :'String',
    :'javadoc_file' => :'String',
    :'package_file' => :'String',
    :'packaging' => :'String',
    :'pom_file' => :'String',
    :'republish' => :'BOOLEAN',
    :'sbt_version' => :'String',
    :'scala_version' => :'String',
    :'sources_file' => :'String',
    :'tags' => :'String',
    :'tests_file' => :'String',
    :'version' => :'String',
    :'vulnerability_counts' => :'WebOSVSeverityCounts'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      artifact_id == o.artifact_id &&
      extra_files == o.extra_files &&
      group_id == o.group_id &&
      is_malware_detected == o.is_malware_detected &&
      ivy_file == o.ivy_file &&
      javadoc_file == o.javadoc_file &&
      package_file == o.package_file &&
      packaging == o.packaging &&
      pom_file == o.pom_file &&
      republish == o.republish &&
      sbt_version == o.sbt_version &&
      scala_version == o.scala_version &&
      sources_file == o.sources_file &&
      tags == o.tags &&
      tests_file == o.tests_file &&
      version == o.version &&
      vulnerability_counts == o.vulnerability_counts
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 268

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CloudsmithApi.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 334

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 247

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


234
235
236
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 234

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



240
241
242
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 240

def hash
  [artifact_id, extra_files, group_id, is_malware_detected, ivy_file, javadoc_file, package_file, packaging, pom_file, republish, sbt_version, scala_version, sources_file, tags, tests_file, version, vulnerability_counts].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
197
198
199
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 192

def list_invalid_properties
  invalid_properties = Array.new
  if @package_file.nil?
    invalid_properties.push('invalid value for "package_file", package_file cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 314

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



320
321
322
323
324
325
326
327
328
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 320

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



308
309
310
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 308

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
# File 'lib/cloudsmith-api/models/maven_package_upload_request.rb', line 203

def valid?
  return false if @package_file.nil?
  true
end