Class: CloudsmithApi::OrganizationMembership

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudsmith-api/models/organization_membership.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OrganizationMembership

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 103

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.has_key?(:'has_two_factor')
    self.has_two_factor = attributes[:'has_two_factor']
  end

  if attributes.has_key?(:'joined_at')
    self.joined_at = attributes[:'joined_at']
  end

  if attributes.has_key?(:'last_login_at')
    self. = attributes[:'last_login_at']
  end

  if attributes.has_key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.has_key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.has_key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.has_key?(:'user_name')
    self.user_name = attributes[:'user_name']
  end

  if attributes.has_key?(:'user_url')
    self.user_url = attributes[:'user_url']
  end

  if attributes.has_key?(:'visibility')
    self.visibility = attributes[:'visibility']
  end
end

Instance Attribute Details

#emailObject

Returns the value of attribute email.



18
19
20
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 18

def email
  @email
end

#has_two_factorObject

Returns the value of attribute has_two_factor.



21
22
23
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 21

def has_two_factor
  @has_two_factor
end

#joined_atObject

Returns the value of attribute joined_at.



24
25
26
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 24

def joined_at
  @joined_at
end

#last_login_atObject

Returns the value of attribute last_login_at.



27
28
29
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 27

def 
  
end

#roleObject

Returns the value of attribute role.



30
31
32
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 30

def role
  @role
end

#userObject

Returns the value of attribute user.



33
34
35
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 33

def user
  @user
end

#user_idObject

Returns the value of attribute user_id.



36
37
38
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 36

def user_id
  @user_id
end

#user_nameObject

Returns the value of attribute user_name.



39
40
41
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 39

def user_name
  @user_name
end

#user_urlObject

Returns the value of attribute user_url.



42
43
44
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 42

def user_url
  @user_url
end

#visibilityObject

Returns the value of attribute visibility.



45
46
47
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 45

def visibility
  @visibility
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 70

def self.attribute_map
  {
    :'email' => :'email',
    :'has_two_factor' => :'has_two_factor',
    :'joined_at' => :'joined_at',
    :'last_login_at' => :'last_login_at',
    :'role' => :'role',
    :'user' => :'user',
    :'user_id' => :'user_id',
    :'user_name' => :'user_name',
    :'user_url' => :'user_url',
    :'visibility' => :'visibility'
  }
end

.swagger_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 86

def self.swagger_types
  {
    :'email' => :'String',
    :'has_two_factor' => :'BOOLEAN',
    :'joined_at' => :'String',
    :'last_login_at' => :'String',
    :'role' => :'String',
    :'user' => :'String',
    :'user_id' => :'String',
    :'user_name' => :'String',
    :'user_url' => :'String',
    :'visibility' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
      has_two_factor == o.has_two_factor &&
      joined_at == o.joined_at &&
       == o. &&
      role == o.role &&
      user == o.user &&
      user_id == o.user_id &&
      user_name == o.user_name &&
      user_url == o.user_url &&
      visibility == o.visibility
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 240

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = CloudsmithApi.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 306

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 219

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 206

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



212
213
214
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 212

def hash
  [email, has_two_factor, joined_at, , role, user, user_id, user_name, user_url, visibility].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



152
153
154
155
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 152

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



286
287
288
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 286

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
295
296
297
298
299
300
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 292

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



280
281
282
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 280

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



159
160
161
162
163
164
165
# File 'lib/cloudsmith-api/models/organization_membership.rb', line 159

def valid?
  role_validator = EnumAttributeValidator.new('String', ['Owner', 'Manager', 'Member', 'Collaborator'])
  return false unless role_validator.valid?(@role)
  visibility_validator = EnumAttributeValidator.new('String', ['Public', 'Private'])
  return false unless visibility_validator.valid?(@visibility)
  true
end