Class: CloudsmithApi::ReposApi
- Inherits:
-
Object
- Object
- CloudsmithApi::ReposApi
- Defined in:
- lib/cloudsmith-api/api/repos_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ReposApi
constructor
A new instance of ReposApi.
-
#repos_all_list(opts = {}) ⇒ Array<Repository>
Get a list of all repositories associated with current user.
-
#repos_all_list_with_http_info(opts = {}) ⇒ Array<(Array<Repository>, Fixnum, Hash)>
Get a list of all repositories associated with current user.
-
#repos_create(owner, opts = {}) ⇒ RepositoryCreate
Create a new repository in a given namespace.
-
#repos_create_with_http_info(owner, opts = {}) ⇒ Array<(RepositoryCreate, Fixnum, Hash)>
Create a new repository in a given namespace.
-
#repos_delete(owner, identifier, opts = {}) ⇒ nil
Delete a repository in a given namespace.
-
#repos_delete_with_http_info(owner, identifier, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Delete a repository in a given namespace.
-
#repos_list(owner, opts = {}) ⇒ Array<Repository>
Get a list of all repositories within a namespace.
-
#repos_list_with_http_info(owner, opts = {}) ⇒ Array<(Array<Repository>, Fixnum, Hash)>
Get a list of all repositories within a namespace.
-
#repos_partial_update(owner, identifier, opts = {}) ⇒ Repository
Update details about a repository in a given namespace.
-
#repos_partial_update_with_http_info(owner, identifier, opts = {}) ⇒ Array<(Repository, Fixnum, Hash)>
Update details about a repository in a given namespace.
-
#repos_read(owner, identifier, opts = {}) ⇒ Repository
Get a specific repository.
-
#repos_read_with_http_info(owner, identifier, opts = {}) ⇒ Array<(Repository, Fixnum, Hash)>
Get a specific repository.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#repos_all_list(opts = {}) ⇒ Array<Repository>
Get a list of all repositories associated with current user. Get a list of all repositories associated with current user.
28 29 30 31 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 28 def repos_all_list(opts = {}) data, _status_code, _headers = repos_all_list_with_http_info(opts) data end |
#repos_all_list_with_http_info(opts = {}) ⇒ Array<(Array<Repository>, Fixnum, Hash)>
Get a list of all repositories associated with current user. Get a list of all repositories associated with current user.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 39 def repos_all_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_all_list ...' end # resource path local_var_path = '/repos/' # query parameters query_params = {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Array<Repository>') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_all_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_create(owner, opts = {}) ⇒ RepositoryCreate
Create a new repository in a given namespace. Create a new repository in a given namespace.
78 79 80 81 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 78 def repos_create(owner, opts = {}) data, _status_code, _headers = repos_create_with_http_info(owner, opts) data end |
#repos_create_with_http_info(owner, opts = {}) ⇒ Array<(RepositoryCreate, Fixnum, Hash)>
Create a new repository in a given namespace. Create a new repository in a given namespace.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 89 def repos_create_with_http_info(owner, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_create ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_create" end # resource path local_var_path = '/repos/{owner}/'.sub('{' + 'owner' + '}', owner.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'data']) auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'RepositoryCreate') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_delete(owner, identifier, opts = {}) ⇒ nil
Delete a repository in a given namespace. Delete a repository in a given namespace.
132 133 134 135 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 132 def repos_delete(owner, identifier, opts = {}) repos_delete_with_http_info(owner, identifier, opts) nil end |
#repos_delete_with_http_info(owner, identifier, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>
Delete a repository in a given namespace. Delete a repository in a given namespace.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 143 def repos_delete_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_delete ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_delete" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_delete" end # resource path local_var_path = '/repos/{owner}/{identifier}/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names) if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_list(owner, opts = {}) ⇒ Array<Repository>
Get a list of all repositories within a namespace. Get a list of all repositories within a namespace.
188 189 190 191 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 188 def repos_list(owner, opts = {}) data, _status_code, _headers = repos_list_with_http_info(owner, opts) data end |
#repos_list_with_http_info(owner, opts = {}) ⇒ Array<(Array<Repository>, Fixnum, Hash)>
Get a list of all repositories within a namespace. Get a list of all repositories within a namespace.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 200 def repos_list_with_http_info(owner, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_list ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_list" end # resource path local_var_path = '/repos/{owner}/'.sub('{' + 'owner' + '}', owner.to_s) # query parameters query_params = {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Array<Repository>') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_partial_update(owner, identifier, opts = {}) ⇒ Repository
Update details about a repository in a given namespace. Update details about a repository in a given namespace.
244 245 246 247 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 244 def repos_partial_update(owner, identifier, opts = {}) data, _status_code, _headers = repos_partial_update_with_http_info(owner, identifier, opts) data end |
#repos_partial_update_with_http_info(owner, identifier, opts = {}) ⇒ Array<(Repository, Fixnum, Hash)>
Update details about a repository in a given namespace. Update details about a repository in a given namespace.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 256 def repos_partial_update_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_partial_update ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_partial_update" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_partial_update" end # resource path local_var_path = '/repos/{owner}/{identifier}/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'data']) auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Repository') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repos_read(owner, identifier, opts = {}) ⇒ Repository
Get a specific repository. Get a specific repository.
303 304 305 306 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 303 def repos_read(owner, identifier, opts = {}) data, _status_code, _headers = repos_read_with_http_info(owner, identifier, opts) data end |
#repos_read_with_http_info(owner, identifier, opts = {}) ⇒ Array<(Repository, Fixnum, Hash)>
Get a specific repository. Get a specific repository.
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/cloudsmith-api/api/repos_api.rb', line 314 def repos_read_with_http_info(owner, identifier, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ReposApi.repos_read ...' end # verify the required parameter 'owner' is set if @api_client.config.client_side_validation && owner.nil? fail ArgumentError, "Missing the required parameter 'owner' when calling ReposApi.repos_read" end # verify the required parameter 'identifier' is set if @api_client.config.client_side_validation && identifier.nil? fail ArgumentError, "Missing the required parameter 'identifier' when calling ReposApi.repos_read" end # resource path local_var_path = '/repos/{owner}/{identifier}/'.sub('{' + 'owner' + '}', owner.to_s).sub('{' + 'identifier' + '}', identifier.to_s) # query parameters query_params = {} # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['apikey'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Repository') if @api_client.config.debugging @api_client.config.logger.debug "API called: ReposApi#repos_read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |